@@ -33,7 +33,7 @@ echo "Installing node modules..."
 runuser -u ${gitlab_user} -- sh -c 'install -d /var/lib/gitlab/.node_modules'
 runuser -u ${gitlab_user} -- sh -c 'yarnpkg install'
 # Remove write permissions of .yarn-metadata.json files
-runuser -u ${gitlab_user} -- sh -c 'find /var/lib/gitlab/.cache/yarn/v4/ -name .yarn-metadata.json -perm -a=w -exec chmod 644 {} \;'
+runuser -u ${gitlab_user} -- sh -c 'test -d "/var/lib/gitlab/.cache/yarn/v6" && find /var/lib/gitlab/.cache/yarn/v6/ -name .yarn-metadata.json -perm -a=w -exec chmod 644 {} \;'
 
 echo "Precompiling locales..."
 runuser -u ${gitlab_user} -- sh -c '/usr/bin/bundle exec rake gettext:po_to_json'
@@ -42,6 +42,4 @@ echo "Precompiling assets..."
 runuser -u ${gitlab_user} -- sh -c '/usr/bin/bundle exec rake tmp:cache:clear assets:precompile'
 
 echo "Webpacking..."
-#runuser -u ${gitlab_user} -- sh -c 'rm -rf node_modules/webpack'
-#runuser -u ${gitlab_user} -- sh -c 'rm -rf node_modules/webpack-bundle-analyzer'
-runuser -u ${gitlab_user} -- sh -c 'node_modules/.bin/webpack --config config/webpack.config.js'
+runuser -u ${gitlab_user} -- sh -c 'webpack --config config/webpack.config.js'
