@@ -11,6 +11,6 @@ then
   echo "---------------------"
   comm -13 debian/upstream-file-list.new debian/upstream-file-list
   echo "---------------------"
-  echo "\nAfter updating, rename 'debian/upstream-file-list.new' as 'debian/upstream-file-list'\n"
+  echo "\nAfter updating the ignore and install files, rename 'debian/upstream-file-list.new' as 'debian/upstream-file-list'. If not using dpkg-buildpackage, generate 'debian/upstream-file-list.new' manually and then rename.\n"
   exit 1
 fi
